@@ -1,6 +1,6 @@
 #!/bin/sh
 #set -xv
-UPGRADE_VER="0.0.8"
+UPGRADE_VER="0.0.9"
 BIN_PATH="/home/root"
 CARD_PATH=${MOUNTR}
 UPGRADE_MD5="upgrade.md5"
@@ -29,6 +29,7 @@ do_reboot() {
     rm -f ${CARD_PATH}/${UPGRADE_MD5} ${CARD_PATH}/${NWRITE_NAME} ${CARD_PATH}/${PROD_NAME}
     rm -f ${CARD_PATH}/*.ta_
     rm -f ${CARD_PATH}/${UPGRADE_SH}
+    rm -f ${CARD_PATH}/digest.sign
 #  fi
   echo "Message:${2}" | tee -a ${LOG}
   # !The next should be the lats message in uploading.log!
@@ -57,7 +58,7 @@ do_sys_check() {
  chk_len=$(ls -l $chk_name | awk '{split($0,x," ");printf("%s",x[5])}')
  dd_len=$(($chk_len/512+1))
  chk_hash="n/a"
- $NAND_WR -d ${3} -o $2 -r ${chk_name}.out ${chk_len} | tee -a ${LOG}
+ $NAND_WR -d ${3} -o $2 -r ${chk_name}.out ${chk_len}
  if [ $? -eq 0 ]; then
   chk_hash=`cat ${chk_name}.out | md5sum | awk '{split($0,x," ");printf("%s",x[1])}'`
  else
@@ -84,7 +85,7 @@ do_sys_write() {
  if [ $ret -ne 0 ]; then
   echo "[$(cat /proc/uptime | cut -d ' ' -f1)] wr img:${1} to dev:${3} offs:${2}" | tee -a ${LOG}
   /usr/local/bin/wd_ping -1 > /dev/null
-  $NAND_WR -d ${3} -o ${2} -i ${CARD_PATH}/${1} | tee -a ${LOG}
+  $NAND_WR -d ${3} -o ${2} -i ${CARD_PATH}/${1}
   if [ $? -ne 0 ]; then
 	echo "[$(cat /proc/uptime | cut -d ' ' -f1)] ${1} record failure" | tee -a ${LOG}
 	ret=1
@@ -122,36 +123,35 @@ pwd | tee -a ${LOG}
 tar -x${TAR_OPT} ${TAR_FILE} ${PROD_NAME}
 ls -l * | tee -a ${LOG}
 
-fl_check_war=0
-prod_ver="$(cat /home/root/productVersion.txt)"
-if [[ "${prod_ver:0:2}" == "1." || "${prod_ver:0:2}" == "2." ]]; then
- fl_check_war=1
-fi
-echo "Check ver $prod_ver [${prod_ver:0:2}] fl_check_war:${fl_check_war}"
-if [ $fl_check_war -ne 1 ]; then
- if [ ! "$(cat ${BIN_PATH}/${PROD_NAME} | awk '{split($0,x,"_");printf("%s",x[2])}')" == "rescue" ]; then
-  WAR_FILE=${BIN_PATH}/${WARTOOL}
-  if [ -f ${WAR_FILE} ]; then
-   echo "Checking Warr at " $(date) | tee -a ${LOG}
-   ${WAR_FILE} ./${PROD_NAME}
-   if [ $? -eq 0 ]; then
-    echo "Error to upgrade. Warranty period exceeds !!!" | tee -a ${LOG}
-    echo "Ending upgrade script at " $(date) | tee -a ${LOG}
-    echo "SMOD 0" > /proc/sp4
-    echo "UCMD STRT" > /proc/sp4
-    echo "UERR 1" > /proc/sp4
-    do_reboot -1 "Not Allowed"
-   fi
-  fi
- else
-  echo "Rescue mode. Skip Warr"
+if [ ! "$(cat ${BIN_PATH}/${PROD_NAME} | awk '{split($0,x,"_");printf("%s",x[2])}')" == "rescue" ]; then
+WAR_FILE=${BIN_PATH}/${WARTOOL}
+ if [ -f ${WAR_FILE} ]; then
+ echo "Checking Warr at " $(date) | tee -a ${LOG}
+ ${WAR_FILE} ./${PROD_NAME}
+ if [ $? -eq 0 ]; then
+  echo "Error to upgrade. Warranty period exceeds !!!" | tee -a ${LOG}
+  echo "Ending upgrade script at " $(date) | tee -a ${LOG}
+  echo "SMOD 0" > /proc/sp4
+  echo "UCMD STRT" > /proc/sp4
+  echo "UERR 1" > /proc/sp4
+  do_reboot -1 "Not Allowed"
  fi
+fi
 else
-  echo "Skip Warr for ver $prod_ver [${prod_ver:0:2}]"
+ echo "Rescue mode. Skip Warr"
 fi
 
 fl_kupl=0
 /usr/local/bin/blaze_leds on FF
+
+mntname=$(echo ${CARD_PATH} | awk '{split($0,x,"/");printf("%s",x[3])}')
+freelen=`df | grep ${mntname} | awk '{split($0,x," ");printf("%s",x[4])}'` 
+echo "[$(cat /proc/uptime | cut -d ' ' -f1)] ${mntname} free space ${freelen}"
+if [ $((freelen/1024)) -lt 70 ]; then 
+     echo "Low free space on ${CARD_PATH}, ${mntname} free space ${freelen}"
+     do_reboot -1 "Low free space. Update skipped. Exiting"
+fi
+
 flist="`tar -t$TAR_OPT $TAR_FILE`"
 echo "flist:$flist" | tee -a ${LOG}
 fl_rfs=`echo $flist | grep -c "$RTFS_NAME"`
